@@ -20,9 +20,11 @@
 #include "or.h"
 #include "connection.h"
 #include "connection_or.h"
-#include "ext_orport.h"
 #include "control.h"
 #include "config.h"
+#include "crypto_rand.h"
+#include "crypto_util.h"
+#include "ext_orport.h"
 #include "main.h"
 #include "proto_ext_or.h"
 #include "util.h"
