@@ -9,19 +9,19 @@
 //! The `digests` module contains submodules for specific hash digests
 //! and extendable output functions.
 //!
-//! ```
-//! use crypto::digests::sha256::Sha256;
+//! ```rust,no_run
+//! use crypto::digests::sha2::*;
 //!
-//! let hasher: Sha256 = Sha256::default();
+//! let mut hasher: Sha256 = Sha256::default();
 //! let mut result: [u8; 32] = [0u8; 32];
 //!
-//! hasher.input("foo");
-//! hasher.input("bar");
-//! hasher.input("baz");
+//! hasher.input(b"foo");
+//! hasher.input(b"bar");
+//! hasher.input(b"baz");
 //!
-//! result.copy_from_slice(hasher.result().as_bytes());
+//! result.copy_from_slice(hasher.result().as_slice());
 //!
-//! assert!(result == "XXX");
+//! assert!(result == [b'X'; DIGEST256_LEN]);
 //! ```
 
 #[deny(missing_docs)]
@@ -29,9 +29,17 @@
 // External crates from cargo or TOR_RUST_DEPENDENCIES.
 extern crate digest;
 extern crate libc;
+extern crate rand_core;
+
+// External dependencies for tests.
+#[cfg(test)]
+extern crate rand as rand_crate;
 
 // Our local crates.
 extern crate external;
+#[cfg(not(test))]
+#[macro_use]
+extern crate tor_log;
 
 pub mod digests;  // Unfortunately named "digests" plural to avoid name conflict with the digest crate
-
+pub mod rand;
